/**
 * Copyright (c) 2021, WSO2 Inc. (http://www.wso2.com). All Rights Reserved.
 *
 * This software is the property of WSO2 Inc. and its suppliers, if any.
 * Dissemination of any information or reproduction of any material contained
 * herein in any form is strictly forbidden, unless permitted by WSO2 expressly.
 * You may not alter or remove any copyright or other notice from copies of this content."
 */

import { DocumentationLinksExtensionInterface } from "./models/documentation";
import { Config } from "../../features/core/configs";

const documentationBaseUrl: string = Config?.getDeploymentConfig()?.docSiteURL || "https://wso2.com/asgardeo/docs";

export const DocumentationLinksExtension: DocumentationLinksExtensionInterface = {
    common: {
        docsHomePage: documentationBaseUrl
    },
    develop: {
        applications: {
            editApplication: {
                common: {
                    signInMethod: {
                        conditionalAuthenticaion: {
                            apiReference: documentationBaseUrl + "/references/conditional-auth/api-reference/",
                            learnMore: documentationBaseUrl + "/guides/conditional-auth/",
                            template: {
                                deviceBased: {
                                    learnMore: documentationBaseUrl + "/guides/conditional-auth/new-device-based-template/"
                                },
                                groupBased: {
                                    learnMore: documentationBaseUrl + "/guides/conditional-auth/group-based-template/"
                                },
                                ipBased: {
                                    learnMore: documentationBaseUrl + "/guides/conditional-auth/ip-based-template/"
                                },
                                userAgeBased: {
                                    learnMore: documentationBaseUrl + "/guides/conditional-auth/user-age-based-template/"
                                }
                            }
                        },
                        learnMore: undefined
                    }
                },
                oidcApplication: {
                    advanced: {
                        learnMore: undefined
                    },
                    attributes: {
                        learnMore: documentationBaseUrl + "/guides/applications/user-attributes" +
                            "/enable-attributes-for-oidc-app/"
                    },
                    info: {
                        learnMore: documentationBaseUrl + "/guides/applications/oidc/discover-oidc-configs/"
                    },
                    protocol: {
                        learnMore: documentationBaseUrl + "/references/app-settings/oidc-settings-for-app/"
                    }
                },
                samlApplication: {
                    advanced: {
                        learnMore: undefined
                    },
                    attributes: {
                        learnMore: documentationBaseUrl + "/guides/applications/user-attributes" +
                            "/enable-attributes-for-saml-app/"
                    },
                    info: {
                        learnMore: documentationBaseUrl + "/guides/applications/saml/discover-saml-configs/"
                    },
                    protocol: {
                        learnMore: documentationBaseUrl + "/references/app-settings/saml-settings-for-app/"
                    }
                }
            },
            learnMore: documentationBaseUrl + "/guides/applications/",
            newApplication: {
                oidcApplication: {
                    learnMore: documentationBaseUrl + "/guides/applications/web-app/register-oidc-web-app/"
                },
                samlApplication: {
                    learnMore: documentationBaseUrl + "/guides/applications/web-app/register-saml-web-app/"
                },
                singlePageApplication: {
                    learnMore: documentationBaseUrl + "/guides/applications/spa/register-single-page-app/"
                }
            }
        },
        connections: {
            learnMore: documentationBaseUrl + "/guides/applications/#manage-connections",
            newConnection: {
                enterprise: {
                    oidcLearnMore: documentationBaseUrl + "/guides/connections/enterprise-login/add-oidc-idp-login/",
                    samlLearnMore: documentationBaseUrl + "/guides/connections/enterprise-login/add-saml-idp-login/"
                },
                facebook: {
                    learnMore: documentationBaseUrl + "/guides/connections/social-login/add-facebook-login/"
                },
                github: {
                    learnMore: documentationBaseUrl + "/guides/connections/social-login/add-github-login/"
                },
                google: {
                    learnMore: documentationBaseUrl + "/guides/connections/social-login/add-google-login/"
                },
                learnMore: documentationBaseUrl + "/guides/applications/#manage-connections"
            }
        }
    },
    manage: {
        accountRecovery: {
            passwordRecovery: {
                learnMore: documentationBaseUrl + "/guides/organization-settings/password-recovery/"
            }
        },
        accountSecurity: {
            undefined
        },
        attributes: {
            attributes: {
                learnMore: documentationBaseUrl + "/guides/organization-settings/attributes/manage-attributes/"
            },
            oidcAttributes: {
                learnMore: documentationBaseUrl + "/guides/organization-settings/attributes/manage-oidc-attribute-mappings/"
            },
            scimAttributes: {
                learnMore: documentationBaseUrl + "/guides/organization-settings/attributes/manage-scim2-attribute-mappings/"
            }
        },
        groups: {
            learnMore: documentationBaseUrl + "/guides/users/manage-groups/"
        },
        scopes: {
            undefined
        },
        selfRegistration: {
            learnMore: documentationBaseUrl + "/guides/users/self-service/customer/self-register/"
        },
        users: {
            allUsers: {
                learnMore: documentationBaseUrl + "/guides/users/"
            },
            collaboratorAccounts: {
                learnMore: documentationBaseUrl + "/guides/users/manage-collaborators/",
                roles: {
                    learnMore: documentationBaseUrl + "/references/user-management/user-roles/"
                }
            },
            customerAccounts: {
                learnMore: documentationBaseUrl + "/guides/users/manage-customers/"
            },
            newCollaboratorUser: {
                learnMore: documentationBaseUrl + "/references/user-management/user-roles/"
            }
        }
    }
};
